
function samplenoi= minusith(sample, i)
% Elliminates i-th row in a sample
% Usage
%   samplenoi= minusith(sample, i)
% Input
%   sample - original data
%   i - i-th row 
% Output
%  samplenoi - sample without i-th row
% Example
% Brani 10/20/02

[m,n] = size(sample);
if min(m,n)==1
    sample=sample(:);
    m=max(m,n);
end
if i == 1
  samplenoi = sample(2:m,:);
elseif i == n
  samplenoi = sample(1:(m-1),:);
else 
  samplenoi =[ sample(1:i-1,:); sample(i+1:m,:) ];
end

%--------------Gatech Nonparametric ------------------